@@ -1,7 +1,7 @@
 from collections import namedtuple
 
 Class = namedtuple('Class', 'name doc fields')
-Field = namedtuple('Field', 'type name nullable enum')
+Field = namedtuple('Field', 'type name nullable enum doc')
 Enum = namedtuple('Enum', 'name doc values')
 
 # Generic types
